===============================
Welcome to Ironic Python Agent!
===============================

Overview
========

Ironic Python Agent is an agent for controlling and deploying Ironic controlled
baremetal nodes. Typically run in a ramdisk, the agent exposes a REST API for
provisioning servers.

Index
=====

.. toctree::
  :maxdepth: 1

  install/index
  admin/index
  contributor/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
